﻿# cxgen

v1.0.2.3 created by Armaan Aggarwal on July 17, 2019

This is a little python package that can generate a cx_Freeze setup.py script to 
turn your program into an .exe or .app file!

To know how to use this module, import cxgen and then call: 'cxgen.manual()'

**What's new?**

1. Fixed `include_files` related errors.
2. Added a feature to add a version to your executable.



**Also, this is the final version of cxgen 1. Stay tuned for cxgen 2.0!**